/*
 * Project: MoleCuilder
 * Description: creates and alters molecular systems
 * Copyright (C)  2013 Frederik Heber. All rights reserved.
 * Please see the COPYING file or "Copyright notice" in builder.cpp for details.
 *
 *
 *   This file is part of MoleCuilder.
 *
 *    MoleCuilder is free software: you can redistribute it and/or modify
 *    it under the terms of the GNU General Public License as published by
 *    the Free Software Foundation, either version 2 of the License, or
 *    (at your option) any later version.
 *
 *    MoleCuilder is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    GNU General Public License for more details.
 *
 *    You should have received a copy of the GNU General Public License
 *    along with MoleCuilder.  If not, see <http://www.gnu.org/licenses/>.
 */

/*
 * PotentialDeserializer.cpp
 *
 *  Created on: 09.05.2013
 *      Author: heber
 */

// include config.h
#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

#include "CodePatterns/MemDebug.hpp"

#include "PotentialDeserializer.hpp"

#include <iostream>
#include <sstream>
#include <string>

#include "CodePatterns/Log.hpp"

#include "Potentials/PotentialFactory.hpp"
#include "Potentials/PotentialRegistry.hpp"

void PotentialDeserializer::operator()()
{
  std::string linestring;
  while (serialized.good()) {
    getline(serialized, linestring);
    const std::string whitespace(" \t");
    const size_t strBegin = linestring.find_first_not_of(whitespace);
    const size_t colonpos = linestring.find(":");
    if ((strBegin != std::string::npos) && (colonpos != std::string::npos)) {
      // get potential's token
      const std::string token = linestring.substr(strBegin, colonpos);
      std::stringstream potentialstream(linestring);

      // instantiate type
      EmpiricalPotential *potential =
          static_cast<StreamFactory<EmpiricalPotential>&>(PotentialFactory::getInstance()).
              createInstance(token, potentialstream);

      // and register
      PotentialRegistry::getInstance().registerInstance(potential);

    } else {
      ELOG(2, "Line '" << linestring << "' contains no potential.");
    }
  }
}
